@@ -1,24 +1,15 @@
 //
-// "$Id: Fl_get_key_win32.cxx 4288 2005-04-16 00:13:17Z mike $"
+// "$Id$"
 //
 // WIN32 keyboard state routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2005 by Bill Spitzak and others.
+// Copyright 1998-2010 by Bill Spitzak and others.
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This library is free software. Distribution and use rights are outlined in
+// the file "COPYING" which should have been included with this file.  If this
+// file is missing or damaged, see the license at:
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
+//     http://www.fltk.org/COPYING.php
 //
 // Please report all bugs and problems on the following page:
 //
@@ -73,6 +64,7 @@ static const struct {unsigned short vk, fltk;} vktab[] = {
   {VK_BACK,	FL_BackSpace},
   {VK_TAB,	FL_Tab},
   {VK_CLEAR,	0xff0b/*XK_Clear*/},
+  {0xe2 /*VK_OEM_102*/,	FL_Iso_Key},
   {VK_RETURN,	FL_Enter},
   {VK_PAUSE,	FL_Pause},
   {VK_SCROLL,	FL_Scroll_Lock},
@@ -134,5 +126,5 @@ int Fl::get_key(int k) {
 }
 
 //
-// End of "$Id: Fl_get_key_win32.cxx 4288 2005-04-16 00:13:17Z mike $".
+// End of "$Id$".
 //
